@@ -1,8 +1,7 @@
 from authorizenet import apicontractsv1, apicontrollers
 
 from terminusgps.authorizenet.auth import get_validation_mode
-from terminusgps.authorizenet.constants import ANET_XML_NS
-from terminusgps.authorizenet.controllers import AuthorizenetControllerExecutionError
+from terminusgps.authorizenet.constants import ANET_XMLNS
 from terminusgps.authorizenet.profiles.base import AuthorizenetProfileBase
 
 
@@ -28,16 +27,6 @@ class CustomerProfile(AuthorizenetProfileBase):
         self._email = email
         self._desc = desc
 
-        if not self.id:
-            try:
-                self.id = int(
-                    self._authorizenet_get_customer_profile()
-                    .find(f"{ANET_XML_NS}profile")
-                    .find(f"{ANET_XML_NS}customerProfileId")
-                )
-            except AuthorizenetControllerExecutionError:
-                self.id = self.create()
-
     @property
     def merchant_id(self) -> str:
         """
@@ -46,13 +35,11 @@ class CustomerProfile(AuthorizenetProfileBase):
         :type: :py:obj:`str`
 
         """
-        if self.id and not self._merchant_id:
-            response = self._authorizenet_get_customer_profile()
+        if self.id or self._email and not self._merchant_id:
             self._merchant_id = (
-                response.profile.merchantCustomerId
-                if response is not None
-                and hasattr(response.profile, "merchantCustomerId")
-                else None
+                self._authorizenet_get_customer_profile()
+                .find(f"{ANET_XMLNS}profile")
+                .find(f"{ANET_XMLNS}merchantCustomerId")
             )
         return str(self._merchant_id)
 
@@ -69,12 +56,11 @@ class CustomerProfile(AuthorizenetProfileBase):
         :type: :py:obj:`str`
 
         """
-        if self.id and not self._email:
-            response = self._authorizenet_get_customer_profile()
+        if self.id or self._merchant_id and not self._email:
             self._email = (
-                response.profile.email
-                if response is not None and hasattr(response.profile, "email")
-                else None
+                self._authorizenet_get_customer_profile()
+                .find(f"{ANET_XMLNS}profile")
+                .find(f"{ANET_XMLNS}email")
             )
         return str(self._email)
 
@@ -91,12 +77,11 @@ class CustomerProfile(AuthorizenetProfileBase):
         :type: :py:obj:`str`
 
         """
-        if self.id and not self._desc:
-            response = self._authorizenet_get_customer_profile()
+        if self.id or self._merchant_id or self._email and not self._desc:
             self._desc = (
-                response.profile.description
-                if response is not None and hasattr(response.profile, "description")
-                else None
+                self._authorizenet_get_customer_profile()
+                .find(f"{ANET_XMLNS}profile")
+                .find(f"{ANET_XMLNS}description")
             )
         return str(self._desc)
 
@@ -130,7 +115,7 @@ class CustomerProfile(AuthorizenetProfileBase):
         )
         return int(
             self._authorizenet_create_customer_profile().find(
-                f"{ANET_XML_NS}customerProfileId"
+                f"{ANET_XMLNS}customerProfileId"
             )
         )
 
@@ -167,12 +152,12 @@ class CustomerProfile(AuthorizenetProfileBase):
         """
         payment_profiles = (
             self._authorizenet_get_customer_profile()
-            .find(f"{ANET_XML_NS}profile")
-            .findall(f"{ANET_XML_NS}paymentProfiles")
+            .find(f"{ANET_XMLNS}profile")
+            .findall(f"{ANET_XMLNS}paymentProfiles")
         )
         return (
             [
-                int(profile.find(f"{ANET_XML_NS}customerPaymentProfileId"))
+                int(profile.find(f"{ANET_XMLNS}customerPaymentProfileId"))
                 for profile in payment_profiles
             ]
             if payment_profiles is not None
@@ -189,18 +174,25 @@ class CustomerProfile(AuthorizenetProfileBase):
         """
         address_profiles = (
             self._authorizenet_get_customer_profile()
-            .find(f"{ANET_XML_NS}profile")
-            .findall(f"{ANET_XML_NS}shipToList")
+            .find(f"{ANET_XMLNS}profile")
+            .find(f"{ANET_XMLNS}shipToList")
         )
         return (
             [
-                int(profile.find(f"{ANET_XML_NS}customerAddressId"))
+                int(profile.find(f"{ANET_XMLNS}customerAddressId"))
                 for profile in address_profiles
             ]
             if address_profiles is not None
             else []
         )
 
+    def _get_id(self) -> int:
+        return int(
+            self._authorizenet_get_customer_profile()
+            .find(f"{ANET_XMLNS}profile")
+            .find(f"{ANET_XMLNS}customerProfileId")
+        )
+
     def _generate_customer_profile_ex_type(
         self,
     ) -> apicontractsv1.customerProfileExType:
@@ -266,7 +258,7 @@ class CustomerProfile(AuthorizenetProfileBase):
         if self.id:
             request.customerProfileId = self.id
         if self._merchant_id:
-            request.merchantCustomerId = self._merchant_id
+            request.merchantCustomerId = str(self._merchant_id)
         if self._email:
             request.email = self._email
 
